@@ -2,4 +2,4 @@
 source "$(dirname "${BASH_SOURCE}")/lib/init.sh"
 
 os::log::info "Running e2e tests"
-KUBERNETES_CONFIG=${KUBECONFIG} GOCACHE=off go test -timeout 30m -v ./test/e2e/
\ No newline at end of file
+KUBERNETES_CONFIG=${KUBECONFIG} go test -timeout 30m -v ./test/e2e/
